@@ -706,12 +706,11 @@ anthy_do_print_context(struct anthy_context *ac, int encoding)
 void
 anthy_release_cand_ent(struct cand_ent *ce)
 {
+  assert (ce);
   if (ce->elm) {
     free(ce->elm);
   }
-  if (&ce->str) {
-    anthy_free_xstr_str(&ce->str);
-  }
+  anthy_free_xstr_str(&ce->str);
   free(ce);
 }
 
